@@ -1,6 +1,4 @@
 /***************************************************************************
- *   ctcron.cpp                                                            *
- *   --------------------------------------------------------------------  *
  *   CT Cron Implementation                                                *
  *   --------------------------------------------------------------------  *
  *   Copyright (C) 1999, Gary Meyer <gary@meyer.net>                       *
@@ -77,7 +75,7 @@ CTCron::CTCron(bool _syscron, string _login) :
     }
   }
 
-  if (name == "")
+  if (name.empty())
     name = login;
 
   initialTaskCount      = 0;
@@ -150,14 +148,14 @@ void CTCron::operator = (const CTCron& source)
   assert(!source.syscron);
 
   for (CTVariableIterator i = const_cast<CTCron&>(source).variable.begin();
-    i != source.variable.end(); i++)
+    i != source.variable.end(); ++i)
   {
     CTVariable* tmp = new CTVariable(**i);
     variable.push_back(tmp);
   }
 
   for (CTTaskIterator i = const_cast<CTCron&>(source).task.begin();
-    i != source.task.end(); i++)
+    i != source.task.end(); ++i)
   {
     CTTask* tmp = new CTTask(**i);
     task.push_back(tmp);
@@ -233,14 +231,14 @@ ostream& operator << (ostream& outputStream, const CTCron& cron)
   int itemCount(0);
 
   for (CTVariableIterator i = const_cast<CTCron&>(cron).variable.begin();
-    i != cron.variable.end(); i++)
+    i != cron.variable.end(); ++i)
   {
     outputStream << **i;
     itemCount++;
   }
 
   for (CTTaskIterator i = const_cast<CTCron&>(cron).task.begin();
-    i != cron.task.end(); i++)
+    i != cron.task.end(); ++i)
   {
     outputStream << **i;
     itemCount++;
@@ -258,9 +256,9 @@ ostream& operator << (ostream& outputStream, const CTCron& cron)
 
 CTCron::~CTCron()
 {
-  for (CTTaskIterator i = task.begin(); i != task.end(); i++)
+  for (CTTaskIterator i = task.begin(); i != task.end(); ++i)
     delete *i;
-  for (CTVariableIterator i = variable.begin(); i != variable.end(); i++)
+  for (CTVariableIterator i = variable.begin(); i != variable.end(); ++i)
     delete *i;
 }
 
@@ -283,10 +281,10 @@ void CTCron::apply()
     return;
 
   // mark as applied
-  for (CTTaskIterator i = task.begin(); i != task.end(); i++)
+  for (CTTaskIterator i = task.begin(); i != task.end(); ++i)
     (*i)->apply();
 
-  for (CTVariableIterator i = variable.begin(); i != variable.end(); i++)
+  for (CTVariableIterator i = variable.begin(); i != variable.end(); ++i)
     (*i)->apply();
 
   initialTaskCount = task.size();
@@ -295,10 +293,10 @@ void CTCron::apply()
 
 void CTCron::cancel()
 {
-  for (CTTaskIterator i = task.begin(); i != task.end(); i++)
+  for (CTTaskIterator i = task.begin(); i != task.end(); ++i)
     (*i)->cancel();
 
-  for (CTVariableIterator i = variable.begin(); i != variable.end(); i++)
+  for (CTVariableIterator i = variable.begin(); i != variable.end(); ++i)
     (*i)->cancel();
 }
 
@@ -310,10 +308,10 @@ bool CTCron::dirty()
 
   if (initialVariableCount != variable.size()) isDirty = true;
 
-  for (CTTaskIterator i = task.begin(); i != task.end(); i++)
+  for (CTTaskIterator i = task.begin(); i != task.end(); ++i)
     if ((*i)->dirty()) isDirty = true;
 
-  for (CTVariableIterator i = variable.begin(); i != variable.end(); i++)
+  for (CTVariableIterator i = variable.begin(); i != variable.end(); ++i)
     if ((*i)->dirty()) isDirty = true;
 
   return isDirty;
