@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -90,6 +90,9 @@ DEBDPKG::DEBDPKG():DEB()
 			    "--purge","--remove"));
   paramsUninst.append(new param(i18n("Check Dependencies"),TRUE,TRUE,"--force-depends"));
   paramsUninst.append(new param(i18n("Test (do not uninstall)"),FALSE,FALSE,"--no-act"));
+
+  hasProgram = ifExe("dpkg");
+  
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -143,7 +146,7 @@ void DEBDPKG::listPackages(QPtrList<packageInfo> *pki)
 // Call the script to uninstall packages setting parameters
 // to dpkg dependent on flags, returning whether everyting worked
 //////////////////////////////////////////////////////////////////////////////
-QString DEBDPKG::doUninstall(int uninstallFlags, QString packs, bool &test)
+QString DEBDPKG::doUninstall(int uninstallFlags, const QString &packs, bool &test)
 {
   QString s = "dpkg ";
   // The -r or -p flag is set by setOptions
